import nagiosplugin
import json
from flatten_json import flatten
import urllib.request
import argparse
import re
import sys

UNKNOWN = 3
OK = 0
WARNING = 1
CRITICAL = 2

class HealthCheck():
    def __init__(self=None, url=None, username=None, password=None):
        self.url = url
        self.username = username
        self.password = password


    def _GetJSON(self):
        try:
            if self.url is not None:
                if self.username is not None:
                    password_mgr = urllib.request.HTTPPasswordMgrWithDefaultRealm()
                    top_level_url = self.url
                    password_mgr.add_password(None, top_level_url, self.username, self.password)
                    handler = urllib.request.HTTPBasicAuthHandler(password_mgr)
                    opener = urllib.request.build_opener(handler)
                    with opener.open(self.url) as response:
                        rawJSON = json.loads(response.read().decode())
                        return rawJSON
                else:
                    with urllib.request.urlopen(self.url) as response:
                        rawJSON = json.loads(response.read().decode())
                    return rawJSON

        except Exception as err:
            sys.exit()


    def probe(self):
        self.json = self._GetJSON()

        test = True
        exitCode = 0
        debugstring = ""
        for jsonNode in self.json:
            healthStatus = jsonNode["healthStatus"]
            serviceName = jsonNode["serviceName"]
            regex = re.compile("HEALTHY", re.IGNORECASE)
            strMatch = True if regex.match(healthStatus) else False
            if strMatch is False:
                debugstring = debugstring + serviceName + " " + healthStatus + " " + jsonNode["reason"] + "\n"
                if exitCode is 0 or exitCode is WARNING and healthStatus is "ERROR":
                    exitCode = CRITICAL
            if exitCode is 0 and healthStatus is "WARNING":
                exitCode = WARNING

        print(debugstring)
        return exitCode

def main():
    argp = argparse.ArgumentParser(description=__doc__)
    argp.add_argument('-u',  '--url', help='URL to obtain JSON data.')
    argp.add_argument('-un', '--username', help='Basic auth username')
    argp.add_argument('-p', '--password', help='Basic auth password')
    args = argp.parse_args()

    healthCheck = HealthCheck(url=args.url, username=args.username, password=args.password)
    exitCode = healthCheck.probe()
    raise sys.exit(exitCode)


if __name__ == '__main__':
    main()

