nagios_host 'jnccn.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'harbor',
		'address' => 'jnccn.org',
		'contact_groups' => 'cs_escalation,harbor',
		'notes' => 'Harborside JNCCN Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/HP/pages/571769217/Server+Setup+-+Harborside'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# Checks the homepage of the live JNCCN site and checks for the string 'JNCCN'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!harbor:harbor2018!/!JNCCN!10!20!',
		'notes' => 'Harborside JNCCN Live Site',
		'notes_url' => 'https://www.jnccn.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# Checks the homepage of the live JNCCN site on the first web node and checks for the string 'JNCCN'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Live Homepage: web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Live Homepage: web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!harbor:harbor2018!/!JNCCN!10!20!harbor-web-live4!web-4!',
		'contact_groups' => 'admins_email_only,harbor',
		'notes' => 'Harborside JNCCN Live Site: web-4',
		'notes_url' => 'https://jnccn.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# Checks the homepage of the live JNCCN site on the second web node and checks for the string 'JNCCN'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Live Homepage: web-12' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Live Homepage: web-12',
		'check_command' => 'https_content_check_basic_auth_single_node!harbor:harbor2018!/!JNCCN!10!20!harbor-web-live12!web-12!',
		'contact_groups' => 'admins_email_only,harbor',
		'notes' => 'Harborside JNCCN Live Site: web-12',
		'notes_url' => 'https://jnccn.org/'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search page of the live JNCCN site and checks for the string 'Browse'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!harbor:harbor2018!/browse?level=parent!Browse!10!20!',
		'notes' => 'Harborside JNCCN Live Site',
		'notes_url' => 'https://jnccn.org/browse?level=parent'
end
#------------------------------------------------------------------------------------
# VIEW
# Checks a content view page of the live harbor site for the book at the URL
# /view/journals/jnccn/jnccn-overview.xml.  The title of this journal is "Journal of the National Comprehensive Cancer Network".  This check
# looks for the string 'Comprehensive' in the response.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Live Content View' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Live Content View',
		'check_command' => 'https_content_check_basic_auth!harbor:harbor2018!/view/journals/jnccn/jnccn-overview.xml!Comprehensive!10!20!',
		'notes' => 'JNCCN Live Site',
		'notes_url' => 'https://jnccn.org/view/journals/jnccn/jnccn-overview.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.jnccn.org!/login!harbor:harbor2018!"Harborside Production Management Portal"!20!10',
		'contact_groups' => 'admins_email_only,harbor',
		'notes' => 'JNCCN Live Loader',
		'notes_url' => 'https://admin.jnccn.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'JNCCN' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!harbor.harbor-staging.irl.pubfactory.com!harbor:harbor2018!JNCCN!20!10',
		'contact_groups' => 'admins_email_only,harbor',
		'notes' => 'JNCCN Staging Site',
		'notes_url' => 'https://harbor.harbor-staging.irl.pubfactory.com/'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'JNCCN' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.jnccn.org!/login!harbor:harbor2018!AMS!20!10',
		'contact_groups' => 'admins_email_only,harbor',
		'notes' => 'JNCCN AMX',
		'notes_url' => 'https://ams.jnccn.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'jnccn.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'jnccn.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!www.jnccn.org!harbor:harbor2018!"provisional account"',
		'contact_groups' => 'admins_email_only,harbor',
		'notes' => 'JNCCN Live Site Failopen',
		'notes_url' => 'https://jnccn.org/'
end
